import * as colors from "../../colors.mjs";
import { write } from "../../output.mjs";
import debug from "debug";

/** @type {object} */
const log = debug("palette").extend("gpl");

export const command = "gpl";
export const desc = "Generate a GNU Imp/Inkscape palette";

export function builder(argv) {
  argv
    .option("c", {
      alias: "hue",
      demandOption: true,
      describe: "The hue (0-360) for the base color",
      type: "number",
    })
    .option("s", {
      alias: "secondary",
      default: 5,
      choices: colors.colorList,
      describe: "The color code (0-9) based on the hue",
      type: "number",
    })
    .option("t", {
      alias: "tertiary",
      default: 8,
      choices: colors.colorList,
      describe: "The color code (0-9) based on the hue",
      type: "number",
    })
    .option("n", {
      alias: "name",
      default: "Priduck",
      describe: "The name of the palette",
      type: "string",
    })
    .option("o", {
      alias: "output",
      describe: "The output path for colors.css",
      type: "string",
    });
}

export async function handler(argv) {
  // Start with the header.
  let lines = ["GIMP Palette", `Name: ${argv.name}`, "Columns: 30", ""];

  log("generating GPL palette named", argv.name);
  log("using base hue", argv.hue, "as color 0");
  log("using secondary", argv.secondary, "tertiary", argv.tertiary);

  // Loop through the three primary colors, then the brightness for each one.
  const colorList = [0, argv.secondary, argv.tertiary];

  for (const colorIndex in colorList) {
    const color = colorList[colorIndex];
    const colorName =
      colorIndex == 0 ? "primary" : colorIndex == 1 ? "secondary" : "tertiary";

    for (const brightness of colors.brightnessList) {
      const lch = colors.getLchCss(argv.hue, color, brightness);
      const rgb = colors.getRgbArray(argv.hue, color, brightness);
      const r = rgb[0].toString().padStart(3, " ");
      const g = rgb[1].toString().padStart(3, " ");
      const b = rgb[2].toString().padStart(3, " ");
      const line = `${r} ${g} ${b} ${colorName}-${brightness} # ${lch}`;

      lines.push(line);
    }
  }

  // Write out the results to the console or a file.
  await write(argv, lines);
}
