import { mkdirp } from "mkdirp";
import path from "path";
import fs from "node:fs/promises";
import debug from "debug";

/** @type {object} */
const log = debug("output");

/**
 * Writes the output to either the console if there is no output or it is
 * set to "-", otherwise write it out as a file.
 *
 * @param {{output: string | undefined }} argv
 * @param {string | string[]} output
 */
export async function write(argv, input) {
  // If we are writing to the console, we can just dump it.
  const text = (Array.isArray(input) ? input.join("\n") : input).trim();

  if (!argv.output || argv.output === "-") {
    console.log(text);

    return;
  }

  // Otherwise, we are writing a file, so we need to make sure the directory
  // exists.
  const file = argv.output;
  const dir = path.dirname(file);

  log("writing", file);

  await mkdirp(dir);

  // Now, write out the file.
  await fs.writeFile(file, Buffer.from(text));

  log("wrote", file);
}
